@@ -23,7 +23,11 @@
 
 #include "accountbalanceparser.h"
 
+#if QT_VERSION >= 0x050000
+#include <QtCore/QXmlStreamReader>
+#else
 #include <QtXml/QXmlStreamReader>
+#endif // QT_VERSION
 
 using namespace Attica;
 
