@@ -33,7 +33,11 @@
 #include <QtCore/QProcess>
 #include <QtNetwork/QAuthenticator>
 #include <QtNetwork/QNetworkReply>
+#if QT_VERSION >= 0x050000
+#include <QtCore/QXmlStreamReader>
+#else
 #include <QtXml/QXmlStreamReader>
+#endif // QT_VERSION
 
 #include "platformdependent.h"
 #include "qtplatformdependent.h"
@@ -70,7 +74,7 @@ public:
 };
 
 
-PlatformDependent* ProviderManager::loadPlatformDependent()
+PlatformDependent* ProviderManager::loadPlatformDependent(const ProviderFlags& flags)
 {
     // OS specific stuff
     #if defined Q_WS_WIN
@@ -81,6 +85,12 @@ PlatformDependent* ProviderManager::loadPlatformDependent()
     #define LIB_EXTENSION "so"
     #endif
 
+    if (flags & ProviderManager::DisablePlugins)
+    {
+        qDebug() << "Disabling provider plugins per application request";
+        return new QtPlatformDependent;
+    }
+
     // use qt plugin dir, if that is not found, fall back to kde plugin path (the old way)
     QStringList paths;
     paths.append(QLibraryInfo::location(QLibraryInfo::PluginsPath));
@@ -120,10 +130,10 @@ PlatformDependent* ProviderManager::loadPlatformDependent()
 }
 
 
-ProviderManager::ProviderManager()
+ProviderManager::ProviderManager(const ProviderFlags& flags)
     : d(new Private)
 {
-    d->m_internals = loadPlatformDependent();
+    d->m_internals = loadPlatformDependent(flags);
     connect(d->m_internals->nam(), SIGNAL(authenticationRequired(QNetworkReply*,QAuthenticator*)), SLOT(authenticate(QNetworkReply*,QAuthenticator*)));
     connect(&d->m_downloadMapping, SIGNAL(mapped(QString)), SLOT(fileFinished(QString)));
 }
@@ -299,7 +309,8 @@ QList<QUrl> ProviderManager::providerFiles() const {
 void ProviderManager::authenticate(QNetworkReply* reply, QAuthenticator* auth)
 {
     QUrl baseUrl;
-    foreach (const QUrl& url, d->m_providers.keys()) {
+    QList<QUrl> urls = d->m_providers.keys();
+    foreach (const QUrl& url, urls) {
         if (url.isParentOf(reply->url())) {
             baseUrl = url;
             break;
