@@ -21,10 +21,8 @@
 
 */
 
-#include <QtTest>
-#include <QtCore>
-#include "attica/person.h"
-#include "../personparser.h"
+#include <QtTest/QtTest>
+#include <personparser.h>
 
 using namespace Attica;
 
@@ -63,4 +61,4 @@ void PersonTest::testParsing()
 
 QTEST_MAIN(PersonTest);
 
-#include "moc_persontest.cxx"
+#include "persontest.moc"
