@@ -1,3 +1,26 @@
+/*
+    This file is part of KDE.
+
+    Copyright 2010 Sebastian Kügler <sebas@kde.org>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
+
 #include "projecttest.h"
 
 #include <QtGui/QLabel>
@@ -36,13 +59,13 @@ ProjectTest::ProjectTest() : QMainWindow(),
     connect(m_editor->build, SIGNAL(clicked()), this, SLOT(createBuildServiceJob()));
     connect(m_editor->cancelJob, SIGNAL(clicked()), this, SLOT(cancelBuildServiceJob()));
     connect(m_editor->updateJob, SIGNAL(clicked()), this, SLOT(updateCurrentProject()));
-    connect(m_editor->buildServices, SIGNAL(currentItemChanged( QListWidgetItem*, QListWidgetItem*)),
-            this, SLOT(selectedBuildServiceChanged( QListWidgetItem*, QListWidgetItem*)));
+    connect(m_editor->buildServices, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)),
+            this, SLOT(selectedBuildServiceChanged(QListWidgetItem*,QListWidgetItem*)));
 
     QAction* a = new QAction(this);
-    a->setText( "Quit" );
+    a->setText( QLatin1String("Quit") );
     connect(a, SIGNAL(triggered()), SLOT(close()) );
-    menuBar()->addMenu( "File" )->addAction( a );
+    menuBar()->addMenu( QLatin1String("File") )->addAction( a );
 
     initOcs();
 }
@@ -53,21 +76,21 @@ ProjectTest::~ProjectTest()
 void ProjectTest::initOcs()
 {
     m_pm.setAuthenticationSuppressed(true);
-    connect(&m_pm, SIGNAL(providerAdded(const Attica::Provider&)), SLOT(providerAdded(const Attica::Provider&)));
+    connect(&m_pm, SIGNAL(providerAdded(Attica::Provider)), SLOT(providerAdded(Attica::Provider)));
     m_pm.loadDefaultProviders();
     m_mainWidget->setEnabled(false);
-    setStatus("Loading providers...");
+    setStatus(QLatin1String("Loading providers..."));
     //connect(m_serviceUpdates.data(), SIGNAL(mapped(QString)), SLOT(serviceUpdates(QString)));
 }
 
 void ProjectTest::providerAdded(const Attica::Provider& provider)
 {
     qDebug() << "providerAdded" << provider.baseUrl();
-    setStatus("Provider found:" + provider.baseUrl().toString());
+    setStatus(QLatin1String("Provider found:") + provider.baseUrl().toString());
     m_mainWidget->setEnabled(true);
 
     if (provider.isValid()) {
-        QString _id = "1";
+        QString _id = QLatin1String("1");
         m_provider = provider;
 
         getProject(_id);
@@ -87,7 +110,7 @@ void ProjectTest::getProject(QString id)
     ItemJob<Project>* job = m_provider.requestProject(id);
     connect(job, SIGNAL(finished(Attica::BaseJob*)), SLOT(projectResult(Attica::BaseJob*)));
     job->start();
-    setStatus(QString("Loading project %").arg(id));
+    setStatus(QString(QLatin1String("Loading project %")).arg(id));
     m_mainWidget->setEnabled(false);
 
 }
@@ -122,15 +145,15 @@ void ProjectTest::projectResult(Attica::BaseJob* j)
     if (j->metadata().error() == Metadata::NoError) {
         Attica::ItemJob<Project> *itemJob = static_cast<Attica::ItemJob<Project> *>( j );
         Attica::Project p = itemJob->result();
-        output.append("Project loaded.");
+        output.append(QLatin1String("Project loaded."));
 
         projectToUi(p);
     } else if (j->metadata().error() == Metadata::OcsError) {
-        output.append(QString("OCS Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("OCS Error: %1")).arg(j->metadata().message()));
     } else if (j->metadata().error() == Metadata::NetworkError) {
-        output.append(QString("Network Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Network Error: %1")).arg(j->metadata().message()));
     } else {
-        output.append(QString("Unknown Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Unknown Error: %1")).arg(j->metadata().message()));
     }
     setStatus(output);
 }
@@ -142,7 +165,7 @@ void ProjectTest::projectToUi(const Project& p)
     m_editor->description->setText(p.description());
     m_editor->url->setText(p.url());
     m_editor->summary->setText(p.summary());
-    m_editor->developers->setText(p.developers().join(", "));
+    m_editor->developers->setText(p.developers().join(QLatin1String(", ")));
     m_editor->license->setText(p.license());
     m_editor->version->setText(p.version());
     m_editor->requirements->setText(p.requirements());
@@ -160,9 +183,9 @@ Project ProjectTest::uiToProject()
     project.setVersion(m_editor->version->text());
     project.setLicense(m_editor->license->text());
     project.setUrl(m_editor->url->text());
-    QStringList _d = m_editor->developers->text().split(',');
+    QStringList _d = m_editor->developers->text().split(QLatin1Char(','));
     QStringList devs;
-    foreach (QString dev, _d) {
+    foreach (const QString& dev, _d) {
         devs << dev.trimmed();
     }
     project.setDevelopers(devs);
@@ -208,13 +231,13 @@ void ProjectTest::createProjectResult(Attica::BaseJob* j)
         Attica::PostJob* postjob = static_cast<Attica::PostJob*>(j);
         m_currentProjectId = j->metadata().resultingId();
         qDebug() << "Yay, no errors ... resulting ID:" << m_currentProjectId;
-        output.append(QString("Project [%1] successfully created:").arg(m_currentProjectId));
+        output.append(QString(QLatin1String("Project [%1] successfully created:")).arg(m_currentProjectId));
     } else if (j->metadata().error() == Metadata::OcsError) {
-        output.append(QString("OCS Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("OCS Error: %1")).arg(j->metadata().message()));
     } else if (j->metadata().error() == Metadata::NetworkError) {
-        output.append(QString("Network Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Network Error: %1")).arg(j->metadata().message()));
     } else {
-        output.append(QString("Unknown Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Unknown Error: %1")).arg(j->metadata().message()));
     }
     setStatus(output);
 }
@@ -229,13 +252,13 @@ void ProjectTest::saveProjectResult(Attica::BaseJob* j)
         Attica::PostJob* postjob = static_cast<Attica::PostJob*>(j);
         m_currentProjectId = j->metadata().resultingId();
         qDebug() << "Yay, no errors ... resulting ID:" << m_currentProjectId;
-        output.append(QString("Project [%1] successfully saved.").arg(m_currentProjectId));
+        output.append(QString(QLatin1String("Project [%1] successfully saved.")).arg(m_currentProjectId));
     } else if (j->metadata().error() == Metadata::OcsError) {
-        output.append(QString("OCS Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("OCS Error: %1")).arg(j->metadata().message()));
     } else if (j->metadata().error() == Metadata::NetworkError) {
-        output.append(QString("Network Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Network Error: %1")).arg(j->metadata().message()));
     } else {
-        output.append(QString("Unknown Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Unknown Error: %1")).arg(j->metadata().message()));
     }
     setStatus(output);
 }
@@ -248,23 +271,23 @@ void ProjectTest::deleteProjectResult(Attica::BaseJob* j)
 
     if (j->metadata().error() == Metadata::NoError) {
         qDebug() << "Yay, no errors ... deleted project.";
-        output.append(QString("Project [%1] successfully deleted").arg(m_currentProjectId));
+        output.append(QString(QLatin1String("Project [%1] successfully deleted")).arg(m_currentProjectId));
     } else if (j->metadata().error() == Metadata::OcsError) {
-        output.append(QString("OCS Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("OCS Error: %1")).arg(j->metadata().message()));
     } else if (j->metadata().error() == Metadata::NetworkError) {
-        output.append(QString("Network Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Network Error: %1")).arg(j->metadata().message()));
     } else {
-        output.append(QString("Unknown Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Unknown Error: %1")).arg(j->metadata().message()));
     }
     setStatus(output);
-    m_currentProjectId = QString();
+    m_currentProjectId.clear();
     projectToUi(Project());
 }
 
 void ProjectTest::projectListResult(Attica::BaseJob* j)
 {
     qDebug() << "Project list job returned";
-    QString output = "<b>Projects:</b>";
+    QString output = QLatin1String("<b>Projects:</b>");
     m_mainWidget->setEnabled(true);
 
     if (j->metadata().error() == Metadata::NoError) {
@@ -275,20 +298,20 @@ void ProjectTest::projectListResult(Attica::BaseJob* j)
         foreach (const Project& p, listJob->itemList()) {
             m_projects[p.id()] = p;
             qDebug() << "New project:" << p.id() << p.name();
-            output.append(QString("<br />%1 (%2)").arg(p.name(), p.id()));
+            output.append(QString(QLatin1String("<br />%1 (%2)")).arg(p.name(), p.id()));
             projectIds << p.id();
             m_editor->projects->insertItem(0, p.name(), p.id());
             // TODO: start project jobs here
         }
         if (!listJob->itemList().count()) {
-            output.append("No Projects found.");
+            output.append(QLatin1String("No Projects found."));
         }
     } else if (j->metadata().error() == Metadata::OcsError) {
-        output.append(QString("OCS Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("OCS Error: %1")).arg(j->metadata().message()));
     } else if (j->metadata().error() == Metadata::NetworkError) {
-        output.append(QString("Network Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Network Error: %1")).arg(j->metadata().message()));
     } else {
-        output.append(QString("Unknown Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Unknown Error: %1")).arg(j->metadata().message()));
     }
     qDebug() << output;
     setStatus(output);
@@ -297,7 +320,7 @@ void ProjectTest::projectListResult(Attica::BaseJob* j)
 void ProjectTest::buildServiceListResult(Attica::BaseJob* j)
 {
     qDebug() << "BuildService list job returned";
-    QString output = "<b>BuildServices:</b>";
+    QString output = QLatin1String("<b>BuildServices:</b>");
     //m_mainWidget->setEnabled(true); // fixme: tab
 
     if (j->metadata().error() == Metadata::NoError) {
@@ -307,7 +330,7 @@ void ProjectTest::buildServiceListResult(Attica::BaseJob* j)
         foreach (const BuildService& bs, listJob->itemList()) {
             m_buildServices[bs.id()] = bs;
             qDebug() << "New OBS:" << bs.id() << bs.name() << bs.url();
-            output.append(QString("<br />%1 (%2) at %3").arg(bs.name(), bs.id(), bs.url()));
+            output.append(QString(QLatin1String("<br />%1 (%2) at %3")).arg(bs.name(), bs.id(), bs.url()));
             QListWidgetItem* new_bs = new QListWidgetItem(bs.name(), m_editor->buildServices);
             new_bs->setData(Qt::UserRole, QVariant(bs.id()));
 
@@ -317,14 +340,14 @@ void ProjectTest::buildServiceListResult(Attica::BaseJob* j)
 
         }
         if (!listJob->itemList().count()) {
-            output.append("No OBS'en found.");
+            output.append(QLatin1String("No OBS'en found."));
         }
     } else if (j->metadata().error() == Metadata::OcsError) {
-        output.append(QString("OCS Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("OCS Error: %1")).arg(j->metadata().message()));
     } else if (j->metadata().error() == Metadata::NetworkError) {
-        output.append(QString("Network Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Network Error: %1")).arg(j->metadata().message()));
     } else {
-        output.append(QString("Unknown Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Unknown Error: %1")).arg(j->metadata().message()));
     }
     qDebug() << output;
     //setBuildStatus(output);
@@ -333,7 +356,7 @@ void ProjectTest::buildServiceListResult(Attica::BaseJob* j)
 void ProjectTest::buildServiceJobListResult(Attica::BaseJob* j)
 {
     qDebug() << "BuildServiceJobList list job returned";
-    QString output = "<b>BuildServiceJobs: </b>";
+    QString output = QLatin1String("<b>BuildServiceJobs: </b>");
     //m_mainWidget->setEnabled(true); // fixme: tab
 
     if (j->metadata().error() == Metadata::NoError) {
@@ -343,19 +366,19 @@ void ProjectTest::buildServiceJobListResult(Attica::BaseJob* j)
         foreach (const BuildServiceJob& bsj, listJob->itemList()) {
             m_buildServiceJobs[bsj.id()] = bsj;
             qDebug() << "New BuildServiceJob:" << bsj.id() << bsj.name() << bsj.target();
-            output.append(QString("<br />%1 (%2) for %3").arg(bsj.name(), bsj.id(), bsj.target()));
+            output.append(QString(QLatin1String("<br />%1 (%2) for %3")).arg(bsj.name(), bsj.id(), bsj.target()));
             QListWidgetItem* new_bsj = new QListWidgetItem(bsj.name(), m_editor->buildServiceJobs);
             new_bsj->setData(Qt::UserRole, QVariant(bsj.id()));
         }
         if (!listJob->itemList().count()) {
-            output.append("No jobs found.");
+            output.append(QLatin1String("No jobs found."));
         }
     } else if (j->metadata().error() == Metadata::OcsError) {
-        output.append(QString("OCS Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("OCS Error: %1")).arg(j->metadata().message()));
     } else if (j->metadata().error() == Metadata::NetworkError) {
-        output.append(QString("Network Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Network Error: %1")).arg(j->metadata().message()));
     } else {
-        output.append(QString("Unknown Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Unknown Error: %1")).arg(j->metadata().message()));
     }
     qDebug() << output;
     //setBuildStatus(output);
@@ -392,7 +415,7 @@ void ProjectTest::createBuildServiceJob()
     Attica::PostJob* j = m_provider.createBuildServiceJob(b);
     connect(j, SIGNAL(finished(Attica::BaseJob*)), this, SLOT(buildServiceJobCreated(Attica::BaseJob*)));
     j->start();
-    setStatus("Starting a build job on the server.");
+    setStatus(QLatin1String("Starting a build job on the server."));
 }
 
 void ProjectTest::cancelBuildServiceJob()
@@ -414,11 +437,11 @@ void ProjectTest::buildServiceJobCanceled(Attica::BaseJob* j)
         qDebug() << "job canceled.";
         // TODO: refresh jobs
     } else if (j->metadata().error() == Metadata::OcsError) {
-        output.append(QString("OCS Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("OCS Error: %1")).arg(j->metadata().message()));
     } else if (j->metadata().error() == Metadata::NetworkError) {
-        output.append(QString("Network Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Network Error: %1")).arg(j->metadata().message()));
     } else {
-        output.append(QString("Unknown Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Unknown Error: %1")).arg(j->metadata().message()));
     }
     qDebug() << output;
     updateCurrentProject();
@@ -434,11 +457,11 @@ void ProjectTest::buildServiceJobCreated(Attica::BaseJob* j)
         qDebug() << "job created. I think.";
         // TODO: refresh jobs
     } else if (j->metadata().error() == Metadata::OcsError) {
-        output.append(QString("OCS Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("OCS Error: %1")).arg(j->metadata().message()));
     } else if (j->metadata().error() == Metadata::NetworkError) {
-        output.append(QString("Network Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Network Error: %1")).arg(j->metadata().message()));
     } else {
-        output.append(QString("Unknown Error: %1").arg(j->metadata().message()));
+        output.append(QString(QLatin1String("Unknown Error: %1")).arg(j->metadata().message()));
     }
     qDebug() << "New BuildServiceJob created with ID:" << j->metadata().resultingId();
     qDebug() << output;
